@@ -10,6 +10,14 @@ class Analyzer:
 
     @staticmethod
     def get_text_language(text: str):
+        """
+        注意：短语尽量不要输入判断，越短越不准，# ’癌症‘判断为‘ja'
+        Args:
+            text:
+
+        Returns:
+
+        """
         return langid.classify(text)[0]
 
     @staticmethod
@@ -121,7 +129,35 @@ class Analyzer:
         data_pie.plot.pie(autopct='%.1f%%', title='pie', )
         plt.show()
 
+    @staticmethod
+    def show_bio_data_info(bio_dt: pd.DataFrame, label='DISEASE'):
+        """
+        show bio format data info
+        Args:
+            bio_dt: ["sentence_id", "words", "labels"]
+            label: entity cls
+
+        Returns:
+            info
+        """
+
+        labels = bio_dt.groupby(by=['sentence_id'], sort=False)
+        from zyl_utils.model_utils.models.ner_bio import NerBIO
+        labels = labels.apply(lambda x: x['labels'].tolist())
+        y_true = [set(NerBIO.get_id_entity(l, label=label)) for l in labels]
+        pos = [y for y in y_true if y != set()]
+        neg = [y for y in y_true if y == set()]
+        print(f'数据集大小(句): {len(labels)}句')
+        print(f'其中有实体的样本数: {len(pos)}句')
+        print(f'其中没有实体的样本数: {len(neg)}句')
+        print(f'数据集大小(词): {len(bio_dt)}词')
+        print(f"其中‘O’标签大小(词): {len(bio_dt[bio_dt['labels'] == 'O'])}词")
+        print(f"其中‘B’标签大小(词): {len(bio_dt[bio_dt['labels'].str.startswith('B')])}词")
+        print(f"其中‘I’标签大小(词): {len(bio_dt[bio_dt['labels'].str.startswith('I')])}词")
+
 
 if __name__ == '__main__':
-    a = pd.Series(['a', 'b', 'd', 'a', 'c', 'd', 'b', 'a', 'c', 'a', 'c'])
-    Analyzer.analyze_category_array(data=a)
+    df = pd.read_hdf('/home/zyl/disk/PharmAI/pharm_ai/panel/data/v4/processing_v4_4.h5',
+                     'disease_eval_bio')
+
+    Analyzer.show_bio_data_info(df, label='DISEASE')
