@@ -39,3 +39,9 @@ if __name__ == '__main__':
     print(t)
     print(p)
     print(sunday_match(target=t, pattern=p))
+
+    import pandas as pd
+    dict = pd.read_hdf("/home/zyl/disk/PharmAI/pharm_ai/panel/entry_match/data/v2/disease_retrieval.h5",
+                       'train')
+
+    print('1')
