@@ -5,7 +5,7 @@ import wandb
 from loguru import logger
 from simpletransformers.t5 import T5Model
 
-from ..metrics.ner_metric import entity_recognition_v2
+from ..metrics.ner_metric import entity_recognition_metrics
 
 
 class NerT5:
@@ -264,12 +264,12 @@ class NerT5:
             y_true = prefix_df['true_target_text'].tolist()
             y_pred = prefix_df['pred_target_text'].tolist()
             print(f'{prefix} report:')
-            res_df = entity_recognition_v2(y_true, y_pred, pos_neg_ratio=pos_neg_ratio,
+            res_df = entity_recognition_metrics(y_true, y_pred, pos_neg_ratio=pos_neg_ratio,
                                            self_metric=self_metric)
             eval_res[prefix] = res_df
 
         print(f'sum report:')
-        res_df = entity_recognition_v2(revised_target_texts, revised_pred_target_texts,
+        res_df = entity_recognition_metrics(revised_target_texts, revised_pred_target_texts,
                                        pos_neg_ratio=pos_neg_ratio, self_metric=self_metric)
         eval_res['ner_t5_metric'] = res_df
 
